# **plugins**: installed plugins, codes, rules

Show table of all installed plugins, their version, declared codes prefixes, and matched rules from the config.

+ For plugin name green means that this plugin is used in current config, and red -- isn't.
+ For rule green means "include", and red means "exclude". If rule has no color, it's invalid rule.

![example of the command output](../../assets/plugins.png)
